package com.loafle.bridge.discoveryport;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.loafle.bridge.discoveryhost.DiscoveryHost;
import com.loafle.bridge.discoveryport.type.PortType;
import com.loafle.bridge.discoveryservice.DiscoveryService;

import javax.persistence.*;
import java.util.Date;
import java.util.List;

@Entity
public class DiscoveryPort {

    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    private long id;

    @ManyToOne
    @JoinColumn(nullable = false)
    @JsonIgnore
    private DiscoveryHost host;
    public DiscoveryHost getHost() {
        return host;
    }

    public void setHost(DiscoveryHost host) {
        this.host = host;
    }
    @Column(nullable = false)
    @Enumerated(EnumType.STRING)
    private PortType portType;

    @Column(nullable = false)
    private int portNumber;

    @OneToMany(mappedBy = "port",cascade = CascadeType.ALL)
    private List<ServiceScanHistory> histories;

    @OneToMany(mappedBy = "port" ,cascade = CascadeType.ALL)
    private List<DiscoveryService> services;

    public List<DiscoveryService> getServices() {
        return services;
    }

    public void setServices(List<DiscoveryService> services) {
        this.services = services;
    }

    @Column(columnDefinition = "TIMESTAMP DEFAULT CURRENT_TIMESTAMP", nullable = false, insertable = false, updatable = false)
    private Date createDate;

    @Column(columnDefinition = "TIMESTAMP DEFAULT CURRENT_TIMESTAMP", nullable = false, insertable = false)
    private Date updateDate;

    public DiscoveryPort() {}

    public DiscoveryPort(PortType type, int portNumber) {
        this.portType = type;
        this.portNumber = portNumber;
    }

    public DiscoveryPort(DiscoveryHost host, PortType type, int portNumber) {
        this.host = host;
        this.portType = type;
        this.portNumber = portNumber;
    }


    public long getId() {
        return id;
    }

    public void setId(long id) {
        this.id = id;
    }

    public PortType getPortType() {
        return portType;
    }

    public void setPortType(PortType portType) {
        this.portType = portType;
    }

    public int getPortNumber() {
        return portNumber;
    }

    public void setPortNumber(int portNumber) {
        this.portNumber = portNumber;
    }

    public List<ServiceScanHistory> getHistories() {
        return histories;
    }

    public void setHistories(List<ServiceScanHistory> histories) {
        this.histories = histories;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Date getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(Date updateDate) {
        this.updateDate = updateDate;
    }

    public void mappingChildren(DiscoveryHost discoveryHost) {
        this.setHost(discoveryHost);
        List<ServiceScanHistory> serviceScanHistories = this.getHistories();
        if (serviceScanHistories != null) {
            for (int z = 0 ; z < serviceScanHistories.size() ; ++z) {
                serviceScanHistories.get(z).setPort(this);
            }
        }

        List<DiscoveryService> discoveryServices = this.getServices();
        if (discoveryServices != null) {
            for (int z = 0 ; z < discoveryServices.size() ; ++z) {
                discoveryServices.get(z).setPort(this);
            }
        }
    }
}
